@@ -17,5 +17,5 @@ pub use client::HttpClient;
 pub use config::HttpClientConfig;
 pub use error::{HttpClientError, HttpClientResult};
 pub use qs::QsError;
-pub use request::RequestBuilder;
+pub use request::{FromPayload, Json, RequestBuilder, ToPayload};
 pub use reqwest::Method;
