@@ -1,6 +1,6 @@
 use std::{sync::Arc, time::Duration};
 
-use longbridge_httpcli::{HttpClient, Method};
+use longbridge_httpcli::{HttpClient, Json, Method};
 use longbridge_proto::quote;
 use longbridge_wscli::WsClientError;
 use serde::Deserialize;
@@ -133,12 +133,15 @@ impl QuoteContext {
     ) -> Result<()>
     where
         I: IntoIterator<Item = T>,
-        T: Into<String>,
+        T: AsRef<str>,
     {
         let (reply_tx, reply_rx) = oneshot::channel();
         self.command_tx
             .send(Command::Subscribe {
-                symbols: symbols.into_iter().map(Into::into).collect(),
+                symbols: symbols
+                    .into_iter()
+                    .map(|symbol| normalize_symbol(symbol.as_ref()).to_string())
+                    .collect(),
                 sub_types: sub_types.into(),
                 is_first_push,
                 reply_tx,
@@ -174,12 +177,15 @@ impl QuoteContext {
     pub async fn unsubscribe<I, T>(&self, symbols: I, sub_types: impl Into<SubFlags>) -> Result<()>
     where
         I: IntoIterator<Item = T>,
-        T: Into<String>,
+        T: AsRef<str>,
     {
         let (reply_tx, reply_rx) = oneshot::channel();
         self.command_tx
             .send(Command::Unsubscribe {
-                symbols: symbols.into_iter().map(Into::into).collect(),
+                symbols: symbols
+                    .into_iter()
+                    .map(|symbol| normalize_symbol(symbol.as_ref()).to_string())
+                    .collect(),
                 sub_types: sub_types.into(),
                 reply_tx,
             })
@@ -213,12 +219,12 @@ impl QuoteContext {
     /// ```
     pub async fn subscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
     where
-        T: Into<String>,
+        T: AsRef<str>,
     {
         let (reply_tx, reply_rx) = oneshot::channel();
         self.command_tx
             .send(Command::SubscribeCandlesticks {
-                symbol: symbol.into(),
+                symbol: normalize_symbol(symbol.as_ref()).into(),
                 period,
                 reply_tx,
             })
@@ -229,12 +235,12 @@ impl QuoteContext {
     /// Unsubscribe security candlesticks
     pub async fn unsubscribe_candlesticks<T>(&self, symbol: T, period: Period) -> Result<()>
     where
-        T: Into<String>,
+        T: AsRef<str>,
     {
         let (reply_tx, reply_rx) = oneshot::channel();
         self.command_tx
             .send(Command::UnsubscribeCandlesticks {
-                symbol: symbol.into(),
+                symbol: normalize_symbol(symbol.as_ref()).into(),
                 period,
                 reply_tx,
             })
@@ -984,10 +990,10 @@ impl QuoteContext {
         let resp = self
             .http_cli
             .request(Method::GET, "/v1/watchlist/groups")
-            .response::<Response>()
+            .response::<Json<Response>>()
             .send()
             .await?;
-        Ok(resp.groups)
+        Ok(resp.0.groups)
     }
 
     /// Get real-time quotes
@@ -1204,3 +1210,10 @@ impl QuoteContext {
         Ok(reply_rx.await.map_err(|_| WsClientError::ClientClosed)?)
     }
 }
+
+fn normalize_symbol(symbol: &str) -> &str {
+    match symbol.split_once('.') {
+        Some((_, market)) if market.eq_ignore_ascii_case("HK") => symbol.trim_start_matches('0'),
+        _ => symbol,
+    }
+}
