@@ -12,9 +12,9 @@ impl Config {
         app_key,
         app_secret,
         access_token,
-        http_url = "\"https://openapi.longbridgeapp.com\"",
-        quote_ws_url = "\"wss://openapi-quote.longbridgeapp.com/v2\"",
-        trade_ws_url = "\"wss://openapi-trade.longbridgeapp.com/v2\"",
+        http_url = "https://openapi.longbridgeapp.com",
+        quote_ws_url = "wss://openapi-quote.longbridgeapp.com/v2",
+        trade_ws_url = "wss://openapi-trade.longbridgeapp.com/v2",
         language = Language::EN,
     ))]
     fn py_new(
